@@ -20,3 +20,8 @@ SerolyzeR.env$normalisation_pattern <- paste0(
   SerolyzeR.env$normalisation_types,
   collapse = "|"
 )
+
+SerolyzeR.env$legend_positions <- c("right", "bottom", "left", "top", "none")
+
+SerolyzeR.env$filename_datetime_format <- "%Y%m%d_%H%M%S"
+SerolyzeR.env$report_datetime_format <- "%d-%m-%Y %H:%M"
